@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
 from __future__ import unicode_literals
 
 # Import PyQt5 classes
 from PyQt5.QtGui import *
 from PyQt5.QtCore import *
 from PyQt5.QtWebKit import *
-from PyQt5.QtNetwork import *
 from PyQt5.QtWidgets import *
 from PyQt5.QtWebKitWidgets import *
 from PyQt5.QtPrintSupport import *
@@ -29,6 +29,8 @@ from translate import tr
 
 from numpy import arange, sin, pi
 from backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
+#from backend_qt5agg import NavigationToolbar2QTAgg
+from matplotlib.backend_bases import NavigationToolbar2
 from matplotlib.figure import Figure
 from matplotlib.colors import Colormap
 import matplotlib.cm as cm
@@ -58,7 +60,13 @@ BLANK_DEFAULT_HTML = '''
 # Handler for the views available for each app. Extended implementation of the QTabWidget
 # to provide extra features, e.g. refresh handling, auto focus-un-focus, status color-hinting
 class ViewManager( QTabWidget ):
-
+    ''' 
+    Manager class for the tool views.
+    
+    Inherits from QTabWidget to focusing tabs on add and unfocus-on-refresh. The QTabWidget method
+    is overridden to wrap addView. All other QTabWidget methods and attributes are available.
+    
+    '''
     auto_unfocus_tabs = ['?']
     # Signals
     source_data_updated = pyqtSignal()
@@ -82,7 +90,18 @@ class ViewManager( QTabWidget ):
         self.source_data_updated.connect(self.onRefreshAll)
     
     # A few wrappers to 
-    def addView(self, widget, name, focused=True, unfocus_on_refresh=False, is_dynamic = True, **kwargs):
+    def addView(self, widget, name, focused=True, unfocus_on_refresh=False, **kwargs):
+        '''
+        Add a view to this view manager.
+
+        Adds the specified widget to the ViewManager under a named tab.
+
+        :param widget: The widget to add as a view.
+        :type widget: object inherited from QWidget or views.BaseView
+        :param name: The name of the widget, will be shown on the tab and used as a data-redirector selector.
+        :type name: str
+        :rtype: int tab/view index     
+        '''
         widget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
         # Automagically unfocus the help (+any other equivalent) tabs if were' refreshing a more interesting one
         widget._unfocus_on_refresh = unfocus_on_refresh
@@ -105,9 +124,18 @@ class ViewManager( QTabWidget ):
                     self.setTabEnabled( w, True)
         
     def addTab(self, widget, name, **kwargs):
+        '''
+        Overridden to redirect addTab calls to addView method. Do not use.
+        '''
         self.addView(widget, name, **kwargs)
     
     def autoSelect(self):
+        '''
+        Autoselect one of the current views.
+
+        Iterates through all current views and selects the first that is not flagged `_unfocus_on_refresh`. 
+        This is used primarily to unfocus the help tabs following successful data calculation.
+        '''    
         if self._unfocus_tabs_enabled:
             cw = self.currentWidget()
             if cw._unfocus_on_refresh:
@@ -119,9 +147,16 @@ class ViewManager( QTabWidget ):
                         break
          
 class BaseView():
-    
+    """
+    Base View prototype with stubs and data-handling functions that are generically useful.
+    Sub-class from this if you want to create a new type of view, e.g. supporting an alternative
+    graph rendering engine. If you just want to create a new graph-type you should sub-class
+    from one of the backend specific stubs, e.g. MplView or D3View.
+    """
+        
     _offers_rerender_on_save = False
     is_floatable_view = False
+    is_mpl_toolbar_enabled = False
 
     @property
     def data(self):
@@ -212,8 +247,9 @@ class RenderPageToFile(QWebPage):
 
 class QWebPageJSLog(QWebPage):
     """
-Makes it possible to use a Python logger to print javascript console messages
-"""
+    Redirects Javascript errors to the console (STDOUT) for debugging.
+    """
+
     def __init__(self, parent=None, **kwargs):
         super(QWebPageJSLog, self).__init__(parent, **kwargs)
 
@@ -227,10 +263,17 @@ class QWebPageExtend(QWebPage):
 
         
 class TableView(QTableView):
+    """
+    Modified QTableView with additional metadata for internal use.
+    """
     is_floatable_view = False
-
+    is_mpl_toolbar_enabled = False
 
 class WebView(QWebView, BaseView):
+    """
+    Modified QWebView with internal navigation handling, loadfinished-resize triggers
+    for SVG, HTML, etc.
+    """
 
     def __init__(self, parent, **kwargs):
         super(WebView, self).__init__(None, **kwargs)        
@@ -286,6 +329,12 @@ class WebView(QWebView, BaseView):
 
 class D3View(WebView):
 
+    """
+    Modified QWebView (via WebView) with d3 generated SVG image saving handler.
+    
+    Use this as a basis for any custom d3-based rendering views.
+    """
+
     d3_template = 'd3/figure.svg'
     _offers_rerender_on_save = True
 
@@ -307,7 +356,9 @@ class D3View(WebView):
 
 
 class HTMLView(WebView):
-
+    """
+    Convenience wrapper for WebView for HTML viewing.
+    """
     def __init__(self, parent, html=None, **kwargs):
         super(HTMLView, self).__init__(parent, **kwargs)        
         if html:
@@ -317,6 +368,11 @@ class HTMLView(WebView):
         self.setHtml(html, QUrl('file:///')) 
         
 class StaticHTMLView(HTMLView):
+    """
+    Convenience wrapper for WebView for HTML viewing of non-dynamic content.
+    
+    This is used for tool help files which do not need to refresh on data update.
+    """
     autogenerate = False
 
 
@@ -332,14 +388,37 @@ class WheezyView(WebView):
         self.setHtml(template.render( metadata ),QUrl("~")) 
 
 
+class MplNavigationHandler(NavigationToolbar2):
+    def _init_toolbar(self):
+        pass
+        
+    def draw_rubberband(self, event, x0, y0, x1, y1):
+        height = self.canvas.figure.bbox.height
+        y1 = height - y1
+        y0 = height - y0
+
+        w = abs(x1 - x0)
+        h = abs(y1 - y0)
+
+        rect = [int(val)for val in (min(x0, x1), min(y0, y1), w, h)]
+        self.canvas.drawRectangle(rect)
+        
+
+
 # Matplotlib-based views handler. Extend with render call for specific views (e.g. bar, scatter, heatmap)
 class MplView(FigureCanvas, BaseView):
-
+    """
+    Base class for matplotlib based views. This handles graph canvas setup, toolbar initialisation
+    and figure save options. Subclass for your own graph-specific views.
+    """
     is_floatable_view = True
+    is_mpl_toolbar_enabled = True
 
     """Ultimately, this is a QWidget (as well as a FigureCanvasAgg, etc.)."""
     def __init__(self, parent, width=5, height=4, dpi=100, **kwargs):
 
+        self.v = parent
+
         self.fig = Figure(figsize=(width, height), dpi=dpi)
         self.ax = self.fig.add_subplot(111)
 
@@ -356,6 +435,11 @@ class MplView(FigureCanvas, BaseView):
                                    QSizePolicy.Expanding,
                                    QSizePolicy.Expanding)
         FigureCanvas.updateGeometry(self)
+        
+        # Install navigation handler; we need to provide a Qt interface that can handle multiple 
+        # plots in a window under separate tabs
+        self.navigation = MplNavigationHandler( self )
+        self.navigation.zoom()
 
     def generate(self):
         pass
@@ -495,7 +579,12 @@ class D3SpectraView(D3View):
         
 
 class MplSpectraView(MplView):
-
+    """
+    A matplotlib-based spectra-like lineplot viewer, particular suited to NMR-like spectra.
+    
+    To be extended/replaced to support more generic uses (and general line-chart plotting).
+    Plots different classes in the data as distinct lines (coloured).
+    """
     def __init__(self, parent, **kwargs):
         super(MplSpectraView, self).__init__(parent, **kwargs)        
         self.ax.invert_xaxis()
@@ -546,7 +635,12 @@ class MplSpectraView(MplView):
         
         
 class D3DifferenceView(D3View):
-
+    """
+    A matplotlib-based difference-lineplot viewer.
+    
+    Takes two inputs - line A and B and plots both, highlighting the regions where they differ.
+    """
+    
     d3_template = 'd3/difference.svg'
     
     def generate(self, dso_a, dso_b):
@@ -610,7 +704,11 @@ class D3LegacyView(D3View):
 
 
 class MplScatterView(MplView):
-
+    """
+    A matplotlib-based scatter plot.
+    
+    Plots classes on a unified X,Y scatter plot.
+    """
     def __init__(self, parent, **kwargs):
         super(MplScatterView, self).__init__(parent, **kwargs)        
 
@@ -874,6 +972,11 @@ class MplCategoryBarView(MplView):
         self.draw()
         
 class MplHeatmapView(MplView):
+    """
+    A matplotlib-based heatmap plotter.
+    
+    Plots heatmap data of measurements against class groupings.
+    """
 
     def __init__(self, parent, **kwargs):
         super(MplHeatmapView, self).__init__(parent, **kwargs)        
